@@ -1,4 +1,3 @@
-const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
 const Tp = imports.gi.TelepathyGLib;
@@ -79,25 +78,20 @@ var UndoNotification = new Lang.Class({
         this.parent(label);
 
         this._undo = false;
+        this._closed = false;
 
-        this.connect('destroy', Lang.bind(this, this._onDestroy));
+        this.connect('destroy', () => { this.close(); });
 
         this.addButton(_("Undo"), () => { this._undo = true; });
-
-        this._app = Gio.Application.get_default();
-        this._shutdownId = this._app.connect('prepare-shutdown',
-                                             Lang.bind(this, this.close));
     },
 
     close: function() {
+        if (this._closed)
+            return;
+
+        this._closed = true;
         this.emit(this._undo ? 'undo' : 'closed');
         this.parent();
-    },
-
-    _onDestroy: function() {
-        if (this._shutdownId)
-            this._app.disconnect(this._shutdownId);
-        this._shutdownId = 0;
     }
 });
 
